==> haskell-record-hasfield-1.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-hasfield.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-hasfield
version:              1.0
visibility:           public
id:                   record-hasfield-1.0-1CbskboRa8NDqeGOtzkfiT
key:                  record-hasfield-1.0-1CbskboRa8NDqeGOtzkfiT
license:              BSD-3-Clause
copyright:            Adam Gundry and Neil Mitchell 2018-2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/record-hasfield#readme
synopsis:             A version of GHC.Records as available in future GHCs.
description:
    This package provides a version of "GHC.Records" as it will be after the implementation of
    <https://github.com/ghc-proposals/ghc-proposals/blob/master/proposals/0042-record-set-field.rst GHC proposal #42>,
    plus some helper functions over it.

category:             Development
abi:                  2616b581c676ff55f8ad0d38d678a4d1
exposed:              True
exposed-modules:      GHC.Records.Compat GHC.Records.Extra
import-dirs:          /usr/lib/ghc-8.10.5/site-local/record-hasfield-1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/record-hasfield-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/record-hasfield-1.0
hs-libraries:         HSrecord-hasfield-1.0-1CbskboRa8NDqeGOtzkfiT
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-record-hasfield/html/record-hasfield.haddock

haddock-html:         /usr/share/doc/haskell-record-hasfield/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-record-hasfield-1.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-hasfield.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-hasfield
version:              1.0
visibility:           public
id:                   record-hasfield-1.0-HdLELRPAW1BCNzfCoSWzaw
key:                  record-hasfield-1.0-HdLELRPAW1BCNzfCoSWzaw
license:              BSD-3-Clause
copyright:            Adam Gundry and Neil Mitchell 2018-2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/record-hasfield#readme
synopsis:             A version of GHC.Records as available in future GHCs.
description:
    This package provides a version of "GHC.Records" as it will be after the implementation of
    <https://github.com/ghc-proposals/ghc-proposals/blob/master/proposals/0042-record-set-field.rst GHC proposal #42>,
    plus some helper functions over it.

category:             Development
abi:                  860192b409d0cb48ab4c68fd484b606c
exposed:              True
exposed-modules:      GHC.Records.Compat GHC.Records.Extra
import-dirs:          /usr/lib/ghc-9.0.1/site-local/record-hasfield-1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/record-hasfield-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/record-hasfield-1.0
hs-libraries:         HSrecord-hasfield-1.0-HdLELRPAW1BCNzfCoSWzaw
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-record-hasfield/html/record-hasfield.haddock

haddock-html:         /usr/share/doc/haskell-record-hasfield/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
